@@ -1,9 +1,11 @@
 """Contains the different invocation strategies for calling processors."""
-from abc import ABC
+from functools import partial
+from abc import ABC, abstractmethod
 from enum import Enum
 from typing import Dict, Optional, List, Callable, Any, Union
 
 from .dependencies import call_with_injection, Event
+from .error_handling_strategies import ErrorHandlingStrategy, Bubble
 from .exceptions import InvocationError
 from .result import Result
 
@@ -18,9 +20,12 @@ def _get_processor_name(processor: Any) -> str:
 class InvocationStrategy(ABC):
     """Class defining an abstract invocation strategy."""
 
-    @staticmethod
+    def __init__(self, error_handling_strategy: ErrorHandlingStrategy = Bubble()):
+        self.error_handling_strategy = error_handling_strategy
+
+    @abstractmethod
     def invoke(
-        matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None
+        self, matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None
     ) -> Union[Result, List[Result]]:
         """Invoke one or multiple matching processors."""
 
@@ -28,25 +33,25 @@ class InvocationStrategy(ABC):
 class FirstMatch(InvocationStrategy):
     """Strategy calling the first matching processor."""
 
-    @staticmethod
-    def invoke(matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
-        return Result(
-            processor_name=_get_processor_name(matching[0]),
-            returned_value=call_with_injection(matching[0], event=event, cache=cache),
+    def invoke(self, matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
+        return self.error_handling_strategy.invoke(
+            callable_name=_get_processor_name(matching[0]),
+            callable_=partial(call_with_injection, matching[0], event=event, cache=cache),
         )
 
 
 class AllMatches(InvocationStrategy):
     """Strategy calling all matching processors."""
 
-    @staticmethod
-    def invoke(matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> List[Result]:
+    def invoke(
+        self, matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None
+    ) -> List[Result]:
         results = []
         for match in matching:
             results.append(
-                Result(
-                    processor_name=_get_processor_name(match),
-                    returned_value=call_with_injection(match, event=event, cache=cache),
+                self.error_handling_strategy.invoke(
+                    callable_name=_get_processor_name(match),
+                    callable_=partial(call_with_injection, match, event=event, cache=cache),
                 )
             )
 
@@ -56,23 +61,21 @@ class AllMatches(InvocationStrategy):
 class NoMatches(InvocationStrategy):
     """Strategy not calling any matching processors."""
 
-    @staticmethod
-    def invoke(matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
+    def invoke(self, matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
         if len(matching) >= 2:
             return Result(processor_name=_get_processor_name(None), returned_value=None)
 
-        return FirstMatch.invoke(matching, event=event, cache=cache)
+        return FirstMatch().invoke(matching, event=event, cache=cache)
 
 
 class NoMatchesStrict(InvocationStrategy):
     """Strategy failing when there are multiple matching."""
 
-    @staticmethod
-    def invoke(matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
+    def invoke(self, matching: List[Callable], event: Optional[Event] = None, cache: Optional[Dict] = None) -> Result:
         if len(matching) >= 2:
             raise InvocationError("Multiple matching processors of the same rank")
 
-        return FirstMatch.invoke(matching, event=event, cache=cache)
+        return FirstMatch().invoke(matching, event=event, cache=cache)
 
 
 class InvocationStrategies(Enum):
